@@ -136,12 +136,6 @@ static NSString *inboxFolderName = @"INBOX";
   namespaceDict = [client namespace];
 
   namespace = [namespaceDict objectForKey: @"personal"];
-  // FIXME: Improve MacOSX Ventura support 
-  // Check if the problem will be fixed by Apple or if this fix should be kept in the future
-  // Ticket #5639
-  if ([[context request] isMacOSXVenturaCalendarApp]) {
-    namespace = [namespaceDict objectForKey: @"PERSONAL"];
-  }
   if (namespace)
     [self _appendNamespace: namespace toFolders: folders];
 
@@ -806,6 +800,17 @@ static NSString *inboxFolderName = @"INBOX";
   return encryption;
 }
 
+- (NSString *) smtpEncryption
+{
+  NSString *encryption;
+
+  encryption = [[self _mailAccount] objectForKey: @"smtpEncryption"];
+  if (![encryption length])
+    encryption = @"none";
+
+  return encryption;
+}
+
 - (NSString *) tlsVerifyMode
 {
   NSString *verifyMode;
@@ -817,6 +822,17 @@ static NSString *inboxFolderName = @"INBOX";
   return verifyMode;
 }
 
+- (NSString *) smtpTlsVerifyMode
+{
+  NSString *verifyMode;
+
+  verifyMode = [[self _mailAccount] objectForKey: @"smtpTlsVerifyMode"];
+  if (!verifyMode || ![verifyMode length])
+    verifyMode = @"default";
+
+  return verifyMode;
+}
+
 - (NSMutableString *) imap4URLString
 {
   NSMutableString *imap4URLString;
@@ -855,6 +871,42 @@ static NSString *inboxFolderName = @"INBOX";
   return imap4URLString;
 }
 
+- (NSMutableString *) smtp4URLString
+{
+  NSMutableString *smtp4URLString;
+  NSDictionary *mailAccount;
+  NSString *encryption, *protocol, *smtpServerName;
+  int defaultPort, port;
+
+  mailAccount = [self _mailAccount];
+  smtpServerName = [mailAccount objectForKey: @"smtpServerName"];
+  if(!smtpServerName)
+    return nil; //Auxiliary account can be only configured for imap and not smtp
+  encryption = [mailAccount objectForKey: @"smtpEncryption"];
+  defaultPort = 25;
+  protocol = @"smtp";
+
+  if ([encryption isEqualToString: @"ssl"])
+  {
+    protocol = @"smtps";
+    defaultPort = 465;
+  }
+  else if ([encryption isEqualToString: @"tls"])
+  {
+    protocol = @"smtps";
+    defaultPort = 465;
+  }
+
+  smtp4URLString = [NSMutableString stringWithFormat: @"%@://%@", protocol, smtpServerName];
+  port = [[mailAccount objectForKey: @"smtpPort"] intValue];
+  if (port && port != defaultPort)
+    [smtp4URLString appendFormat: @":%d", port];
+
+  [smtp4URLString appendString: @"/"];
+
+  return smtp4URLString;
+}
+
 - (NSMutableString *) traversalFromMailAccount
 {
   return [NSMutableString string];
@@ -1011,33 +1063,27 @@ static NSString *inboxFolderName = @"INBOX";
   [[[self imap4Connection] client] namespace];
 
   if ([_key hasPrefix: @"folder"])
-    {
-      folderName = [[_key substringFromIndex: 6] fromCSSIdentifier];
+  {
+    folderName = [[_key substringFromIndex: 6] fromCSSIdentifier];
 
-      namespaces = [NSMutableArray array];
-      [self _appendNamespaces: namespaces];
-      if ([namespaces containsObject: folderName])
-        klazz = [SOGoMailNamespace class];
-      else if ([folderName
-		 isEqualToString: [self draftsFolderNameInContext: _ctx]])
-	klazz = [SOGoDraftsFolder class];
-      else if ([folderName
-                 isEqualToString: [self sentFolderNameInContext: _ctx]])
-	klazz = [SOGoSentFolder class];
-      else if ([folderName
-		 isEqualToString: [self trashFolderNameInContext: _ctx]])
-	klazz = [SOGoTrashFolder class];
-      else if ([folderName
-		 isEqualToString: [self junkFolderNameInContext: _ctx]])
-	klazz = [SOGoJunkFolder class];
-      else if ([folderName
-		 isEqualToString: [self templatesFolderNameInContext: _ctx]])
-	klazz = [SOGoTemplatesFolder class];
-      else
-	klazz = [SOGoMailFolder class];
-
-      obj = [klazz objectWithName: _key inContainer: self];
-    }
+    namespaces = [NSMutableArray array];
+    [self _appendNamespaces: namespaces];
+    if ([namespaces containsObject: folderName])
+      klazz = [SOGoMailNamespace class];
+    else if ([folderName isEqualToString: [self draftsFolderNameInContext: _ctx]])
+	    klazz = [SOGoDraftsFolder class];
+    else if ([folderName isEqualToString: [self sentFolderNameInContext: _ctx]])
+	    klazz = [SOGoSentFolder class];
+    else if ([folderName isEqualToString: [self trashFolderNameInContext: _ctx]])
+	    klazz = [SOGoTrashFolder class];
+    else if ([folderName isEqualToString: [self junkFolderNameInContext: _ctx]])
+	    klazz = [SOGoJunkFolder class];
+    else if ([folderName isEqualToString: [self templatesFolderNameInContext: _ctx]])
+	    klazz = [SOGoTemplatesFolder class];
+    else
+	    klazz = [SOGoMailFolder class];
+    obj = [klazz objectWithName: _key inContainer: self];
+  }
   else
     obj = [super lookupName: _key inContext: _ctx acquire: NO];
 
@@ -1222,9 +1268,8 @@ static NSString *inboxFolderName = @"INBOX";
 {
   if (!templatesFolder)
     {
-      templatesFolder
-	= [self folderWithTraversal: [self templatesFolderNameInContext: _ctx]
-                       andClassName: @"SOGoTemplatesFolder"];
+      templatesFolder = [self folderWithTraversal: [self templatesFolderNameInContext: _ctx]
+                                    andClassName: @"SOGoTemplatesFolder"];
       [templatesFolder retain];
     }
 
