@@ -242,7 +242,7 @@
   return ([[cc userAgent] rangeOfString: @"Android"].location != NSNotFound);
 }
 
-- (BOOL) isMacOSXVenturaCalendarApp
+- (BOOL) isMacOSXCalendar
 {
   WEClientCapabilities *cc;
   BOOL b;
@@ -251,7 +251,8 @@
 
   b = (
         (
-          nil != [cc userAgent] && [[cc userAgent] rangeOfString: @"macOS/13"].location != NSNotFound
+          nil != [cc userAgent] 
+          && [[cc userAgent] rangeOfString: @"macOS"].location != NSNotFound
           && [[cc userAgent] rangeOfString: @"dataaccessd"].location != NSNotFound
         )
        );
@@ -259,4 +260,11 @@
   return b;
 }
 
+- (BOOL) isThunderbird
+{
+  BOOL ret;
+  ret = ([[self headerForKey:@"user-agent"] rangeOfString: @"Thunderbird"].location != NSNotFound);
+  return ret;
+}
+
 @end
