@@ -79,6 +79,7 @@ _xmlCharsetForCharset (NSString *charset)
     { @"iso-2022-jp", XML_CHAR_ENCODING_2022_JP},
 //     { @"iso-2022-jp", XML_CHAR_ENCODING_SHIFT_JIS},
     { @"koi8-r", XML_CHAR_ENCODING_ERROR},       // unsupported, will trigger koi8-r -> utf8 conversion
+    { @"koi8-u", XML_CHAR_ENCODING_ERROR},       // unsupported, will trigger koi8-u -> utf8 conversion
     { @"windows-1250", XML_CHAR_ENCODING_ERROR}, // unsupported, will trigger windows-1250 -> utf8 conversion
     { @"windows-1251", XML_CHAR_ENCODING_ERROR}, // unsupported, will trigger windows-1251 -> utf8 conversion
     { @"windows-1255", XML_CHAR_ENCODING_ERROR}, // unsupported, will trigger windows-1255 -> utf8 conversion
@@ -108,6 +109,13 @@ _xmlCharsetForCharset (NSString *charset)
   return encoding;
 }
 
+static NSString *_sanitizeHtmlForDisplay(NSString *content)
+{
+  // Sometimes, the mail contains SOGo mail template in the content, and broke mail display
+  // replace the responsible css
+  return [content stringByReplacingOccurrencesOfString: @"sg-face layout-fill layout-column" withString:@""];;
+}
+
 @interface _UIxHTMLMailContentHandler : NSObject <SaxContentHandler, SaxLexicalHandler>
 {
   NSMutableString *result;
@@ -120,9 +128,11 @@ _xmlCharsetForCharset (NSString *charset)
   BOOL inCSSDeclaration;
   BOOL hasEmbeddedCSS;
   xmlCharEncoding contentEncoding;
+  BOOL rawContent;
 }
 
 - (NSString *) result;
+- (void) activateRawContent;
 
 @end
 
@@ -153,6 +163,7 @@ _xmlCharsetForCharset (NSString *charset)
       ignoreTag = nil;
       attachmentIds = nil;
       contentEncoding = XML_CHAR_ENCODING_UTF8;
+      rawContent = NO;
     }
 
   return self;
@@ -166,6 +177,11 @@ _xmlCharsetForCharset (NSString *charset)
   [super dealloc];
 }
 
+- (void)activateRawContent
+{
+  rawContent = YES;
+}
+
 - (void) setContentEncoding: (xmlCharEncoding) newContentEncoding
 {
   contentEncoding = newContentEncoding;
@@ -368,7 +384,8 @@ _xmlCharsetForCharset (NSString *charset)
                     (*(currentChar-7) == 'p' || *(currentChar-7) == 'P') &&
                     (*(currentChar-8) == 'm' || *(currentChar-8) == 'M') &&
                     (*(currentChar-9) == 'i' || *(currentChar-9) == 'I') &&
-                    *(currentChar-10) == '!'))
+                    *(currentChar-10) == '!')
+                    && !rawContent)
                 {
                   length = (currentChar - start);
                   [declaration appendFormat: @"%@ !important;",
@@ -751,11 +768,17 @@ _xmlCharsetForCharset (NSString *charset)
     {
       handler = nil;
       ex = nil;
+      rawContent = NO;
     }
 
   return self;
 }
 
+- (void)activateRawContent
+{
+  rawContent = YES;
+}
+
 - (void) dealloc
 {
   [handler release];
@@ -797,6 +820,8 @@ _xmlCharsetForCharset (NSString *charset)
              createXMLReaderForMimeType: @"text/html"];
 
   handler = [_UIxHTMLMailContentHandler new];
+  if (rawContent)
+    [handler activateRawContent];
   [handler setAttachmentIds: attachmentIds];
 
   // Some broken email messages have some additionnal content outside the main HTML tags which are
@@ -911,8 +936,11 @@ _xmlCharsetForCharset (NSString *charset)
 {
   if (!handler)
     [self _parseContent];
-      
-  return [handler result];
+  
+  if (rawContent)
+    return [handler result];
+  
+  return _sanitizeHtmlForDisplay([handler result]);
 }
 
 @end
@@ -1064,7 +1092,7 @@ _xmlCharsetForCharset (NSString *charset)
   if (!handler)
     [self _parseContent];
 
-  return [handler result];
+  return _sanitizeHtmlForDisplay([handler result]);
 }
 
 @end
